@@ -225,12 +225,12 @@ XImage *BImage::renderXImage(void) {
     }
 
   if (control->doDither()) {
-    short er, eg, eb, *or, *og, *ob, *nor, *nog, *nob, *por, *pog, *pob;
+    short er, eg, eb, *gor, *og, *ob, *gnor, *nog, *nob, *por, *pog, *pob;
     unsigned short *ort, *ogt, *obt;
     
-    control->getDitherBuffers(width + 2, &or, &og, &ob, &nor, &nog, &nob,
+    control->getDitherBuffers(width + 2, &gor, &og, &ob, &gnor, &nog, &nob,
 			      &ort, &ogt, &obt);
-    if ((! or) || (! og) || (! ob) || (! nor) || (! nog) || (! nob) ||
+    if ((! gor) || (! og) || (! ob) || (! gnor) || (! nog) || (! nob) ||
 	(! ort) || (! ogt) || (! obt)) {
       fprintf(stderr,
 	      "BImage::renderXImage: error getting dither information\n");
@@ -240,7 +240,7 @@ XImage *BImage::renderXImage(void) {
     
     x = width;
 
-    por = or;
+    por = gor;
     pog = og;
     pob = ob;
 
@@ -259,26 +259,26 @@ XImage *BImage::renderXImage(void) {
     for (y = 0, off = 0; y < height; y++) {
       if (y < (height - 1)) {
 	for (x = 0, i = off + width; x < width; x++, i++) {
-	  *(nor + x) = *(red + i);
+	  *(gnor + x) = *(red + i);
 	  *(nog + x) = *(green + i);
 	  *(nob + x) = *(blue + i);
 	}
 	
 	i--;
-	*(nor + x) = *(red + i);
+	*(gnor + x) = *(red + i);
 	*(nog + x) = *(green + i);
 	*(nob + x) = *(blue + i);
       }
       
       for (x = 0; x < width; x++) {
-	if (*(or + x) > 255) *(or + x) = 255;
-	else if (*(or + x) < 0) *(or + x) = 0;
+	if (*(gor + x) > 255) *(gor + x) = 255;
+	else if (*(gor + x) < 0) *(gor + x) = 0;
 	if (*(og + x) > 255) *(og + x) = 255;
 	else if (*(og + x) < 0) *(og + x) = 0;
 	if (*(ob + x) > 255) *(ob + x) = 255;
 	else if (*(ob + x) < 0) *(ob + x) = 0;
 	
-	r = *(tr + *(or + x));
+	r = *(tr + *(gor + x));
 	g = *(tg + *(og + x));
 	b = *(tb + *(ob + x));
 	
@@ -340,19 +340,19 @@ XImage *BImage::renderXImage(void) {
 	  return 0;
 	}
 
-	er = *(or + x) - *(ort + *(or + x));
+	er = *(gor + x) - *(ort + *(gor + x));
 	eg = *(og + x) - *(ogt + *(og + x));
 	eb = *(ob + x) - *(obt + *(ob + x));
 	
-	*(or + x + 1) += er;
+	*(gor + x + 1) += er;
 	*(og + x + 1) += eg;
 	*(ob + x + 1) += eb;
 	
-	*(nor + x) += er;
+	*(gnor + x) += er;
 	*(nog + x) += eg;
 	*(nob + x) += eb;
 	
-	*(nor + x + 1) -= (er >> 1) + (er >> 2);
+	*(gnor + x + 1) -= (er >> 1) + (er >> 2);
 	*(nog + x + 1) -= (eg >> 1) + (eg >> 2);
 	*(nob + x + 1) -= (eb >> 1) + (eb >> 2);
       }
@@ -360,7 +360,7 @@ XImage *BImage::renderXImage(void) {
       off += image->width;
       idata = (pd += image->bytes_per_line);
       
-      por = or; or = nor; nor = por;
+      por = gor; gor = gnor; gnor = por;
       pog = og; og = nog; nog = pog;
       pob = ob; ob = nob; nob = pob;
     }
